# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aoi_collection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61oi_collection.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"|\n\rAOICollection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\ncreated_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x10\n\x08num_aois\x18\x05 \x01(\r\"\x90\x01\n\x07\x41OIInfo\x12\x0e\n\x06\x61oi_id\x18\x01 \x01(\t\x12\x16\n\x0e\x61oi_version_id\x18\x02 \x01(\t\x12\x10\n\x08\x61oi_name\x18\x03 \x01(\t\x12\x0b\n\x03lat\x18\x04 \x01(\x02\x12\x0c\n\x04long\x18\x05 \x01(\x02\x12\x10\n\x08\x61rea_km2\x18\x06 \x01(\x01\x12\x0c\n\x04geom\x18\x07 \x01(\t\x12\x10\n\x08timezone\x18\x08 \x01(\t\"*\n\x1a\x41OICollectionCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"b\n\x1b\x41OICollectionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12.\n\x0e\x61oi_collection\x18\x02 \x01(\x0b\x32\x16.oi.papi.AOICollection\"_\n\x17\x41OICollectionGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07verbose\x18\x02 \x01(\x08\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"|\n\x18\x41OICollectionGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\"\n\x08\x61oi_info\x18\x03 \x03(\x0b\x32\x10.oi.papi.AOIInfo\">\n\x17\x41OICollectionAddRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0f\x61oi_version_ids\x18\x02 \x03(\r\"/\n\x18\x41OICollectionAddResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"A\n\x1a\x41OICollectionRemoveRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0f\x61oi_version_ids\x18\x02 \x03(\r\"2\n\x1b\x41OICollectionRemoveResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"5\n\x19\x41OICollectionCloneRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"L\n\x1a\x41OICollectionCloneResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x19\n\x11\x61oi_collection_id\x18\x02 \x01(\t\"\xc0\x01\n\x18\x41OICollectionListRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x32\n\x0emin_created_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0emax_created_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bsearch_text\x18\x04 \x01(\t\"\x8a\x01\n\x19\x41OICollectionListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12/\n\x0f\x61oi_collections\x18\x03 \x03(\x0b\x32\x16.oi.papi.AOICollection2\xf5\x03\n\x10\x41OICollectionApi\x12S\n\x06\x63reate\x12#.oi.papi.AOICollectionCreateRequest\x1a$.oi.papi.AOICollectionCreateResponse\x12J\n\x03get\x12 .oi.papi.AOICollectionGetRequest\x1a!.oi.papi.AOICollectionGetResponse\x12P\n\x05\x63lone\x12\".oi.papi.AOICollectionCloneRequest\x1a#.oi.papi.AOICollectionCloneResponse\x12J\n\x03\x61\x64\x64\x12 .oi.papi.AOICollectionAddRequest\x1a!.oi.papi.AOICollectionAddResponse\x12S\n\x06remove\x12#.oi.papi.AOICollectionRemoveRequest\x1a$.oi.papi.AOICollectionRemoveResponse\x12M\n\x04list\x12!.oi.papi.AOICollectionListRequest\x1a\".oi.papi.AOICollectionListResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aoi_collection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_AOICOLLECTION']._serialized_start=87
  _globals['_AOICOLLECTION']._serialized_end=211
  _globals['_AOIINFO']._serialized_start=214
  _globals['_AOIINFO']._serialized_end=358
  _globals['_AOICOLLECTIONCREATEREQUEST']._serialized_start=360
  _globals['_AOICOLLECTIONCREATEREQUEST']._serialized_end=402
  _globals['_AOICOLLECTIONCREATERESPONSE']._serialized_start=404
  _globals['_AOICOLLECTIONCREATERESPONSE']._serialized_end=502
  _globals['_AOICOLLECTIONGETREQUEST']._serialized_start=504
  _globals['_AOICOLLECTIONGETREQUEST']._serialized_end=599
  _globals['_AOICOLLECTIONGETRESPONSE']._serialized_start=601
  _globals['_AOICOLLECTIONGETRESPONSE']._serialized_end=725
  _globals['_AOICOLLECTIONADDREQUEST']._serialized_start=727
  _globals['_AOICOLLECTIONADDREQUEST']._serialized_end=789
  _globals['_AOICOLLECTIONADDRESPONSE']._serialized_start=791
  _globals['_AOICOLLECTIONADDRESPONSE']._serialized_end=838
  _globals['_AOICOLLECTIONREMOVEREQUEST']._serialized_start=840
  _globals['_AOICOLLECTIONREMOVEREQUEST']._serialized_end=905
  _globals['_AOICOLLECTIONREMOVERESPONSE']._serialized_start=907
  _globals['_AOICOLLECTIONREMOVERESPONSE']._serialized_end=957
  _globals['_AOICOLLECTIONCLONEREQUEST']._serialized_start=959
  _globals['_AOICOLLECTIONCLONEREQUEST']._serialized_end=1012
  _globals['_AOICOLLECTIONCLONERESPONSE']._serialized_start=1014
  _globals['_AOICOLLECTIONCLONERESPONSE']._serialized_end=1090
  _globals['_AOICOLLECTIONLISTREQUEST']._serialized_start=1093
  _globals['_AOICOLLECTIONLISTREQUEST']._serialized_end=1285
  _globals['_AOICOLLECTIONLISTRESPONSE']._serialized_start=1288
  _globals['_AOICOLLECTIONLISTRESPONSE']._serialized_end=1426
  _globals['_AOICOLLECTIONAPI']._serialized_start=1429
  _globals['_AOICOLLECTIONAPI']._serialized_end=1930
# @@protoc_insertion_point(module_scope)
