# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user_collection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import user_pb2 as user__pb2
try:
  common__models__pb2 = user__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = user__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.user_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15user_collection.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\x1a\nuser.proto\"H\n\x0eUserCollection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1c\n\x05users\x18\x03 \x03(\x0b\x32\r.oi.papi.User\"J\n\x1bUserCollectionCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\x15parent_collection_ids\x18\x02 \x03(\t\"`\n\x1cUserCollectionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12+\n\ncollection\x18\x02 \x01(\x0b\x32\x17.oi.papi.UserCollection\"^\n\x18UserCollectionGetRequest\x12+\n\ncollection\x18\x01 \x01(\x0b\x32\x17.oi.papi.UserCollection\x12\x15\n\rinclude_users\x18\x02 \x01(\x08\"]\n\x19UserCollectionGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12+\n\ncollection\x18\x02 \x01(\x0b\x32\x17.oi.papi.UserCollection\",\n\x19UserCollectionListRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"_\n\x1aUserCollectionListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12,\n\x0b\x63ollections\x18\x02 \x03(\x0b\x32\x17.oi.papi.UserCollection2\x89\x02\n\x11UserCollectionApi\x12U\n\x06\x63reate\x12$.oi.papi.UserCollectionCreateRequest\x1a%.oi.papi.UserCollectionCreateResponse\x12L\n\x03get\x12!.oi.papi.UserCollectionGetRequest\x1a\".oi.papi.UserCollectionGetResponse\x12O\n\x04list\x12\".oi.papi.UserCollectionListRequest\x1a#.oi.papi.UserCollectionListResponseP\x00P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_collection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_USERCOLLECTION']._serialized_start=67
  _globals['_USERCOLLECTION']._serialized_end=139
  _globals['_USERCOLLECTIONCREATEREQUEST']._serialized_start=141
  _globals['_USERCOLLECTIONCREATEREQUEST']._serialized_end=215
  _globals['_USERCOLLECTIONCREATERESPONSE']._serialized_start=217
  _globals['_USERCOLLECTIONCREATERESPONSE']._serialized_end=313
  _globals['_USERCOLLECTIONGETREQUEST']._serialized_start=315
  _globals['_USERCOLLECTIONGETREQUEST']._serialized_end=409
  _globals['_USERCOLLECTIONGETRESPONSE']._serialized_start=411
  _globals['_USERCOLLECTIONGETRESPONSE']._serialized_end=504
  _globals['_USERCOLLECTIONLISTREQUEST']._serialized_start=506
  _globals['_USERCOLLECTIONLISTREQUEST']._serialized_end=550
  _globals['_USERCOLLECTIONLISTRESPONSE']._serialized_start=552
  _globals['_USERCOLLECTIONLISTRESPONSE']._serialized_end=647
  _globals['_USERCOLLECTIONAPI']._serialized_start=650
  _globals['_USERCOLLECTIONAPI']._serialized_end=915
# @@protoc_insertion_point(module_scope)
