# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: permission.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10permission.proto\x12\x12oi.papi.permission\x1a\x13\x63ommon_models.proto\"\xab\x04\n\nPermission\x12\x42\n\rresource_type\x18\x01 \x01(\x0e\x32+.oi.papi.permission.Permission.ResourceType\x12\x14\n\x0cresource_ids\x18\x02 \x03(\t\x12\x13\n\x0bsubject_ids\x18\x03 \x03(\t\x12G\n\x10permission_types\x18\x04 \x03(\x0e\x32-.oi.papi.permission.Permission.PermissionType\"\xda\x01\n\x0cResourceType\x12$\n UNKNOWN_PERMISSION_RESOURCE_TYPE\x10\x00\x12\r\n\tALGORITHM\x10\x01\x12\x19\n\x15\x41LGORITHM_COMPUTATION\x10\x02\x12\x14\n\x10\x41LGORITHM_CONFIG\x10\x03\x12\x0c\n\x08\x41NALYSIS\x10\x04\x12\x18\n\x14\x41NALYSIS_COMPUTATION\x10\x05\x12\x13\n\x0f\x41NALYSIS_CONFIG\x10\x06\x12\x12\n\x0e\x41OI_COLLECTION\x10\x07\x12\n\n\x06RESULT\x10\x08\x12\x07\n\x03TOI\x10\t\"M\n\x0ePermissionType\x12\x1b\n\x17UNKNOWN_PERMISSION_TYPE\x10\x00\x12\x08\n\x04READ\x10\x01\x12\t\n\x05WRITE\x10\x02\x12\t\n\x05\x41\x44MIN\x10\x03\"9\n\x0e\x43ollectionType\x12\x1b\n\x17UNKNOWN_COLLECTION_TYPE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\"N\n\x17PermissionCreateRequest\x12\x33\n\x0bpermissions\x18\x01 \x03(\x0b\x32\x1e.oi.papi.permission.Permission\"/\n\x18PermissionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"N\n\x17PermissionDeleteRequest\x12\x33\n\x0bpermissions\x18\x01 \x03(\x0b\x32\x1e.oi.papi.permission.Permission\"/\n\x18PermissionDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xd9\x01\n\rPermissionApi\x12\x63\n\x06\x63reate\x12+.oi.papi.permission.PermissionCreateRequest\x1a,.oi.papi.permission.PermissionCreateResponse\x12\x63\n\x06\x64\x65lete\x12+.oi.papi.permission.PermissionDeleteRequest\x1a,.oi.papi.permission.PermissionDeleteResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'permission_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PERMISSION']._serialized_start=62
  _globals['_PERMISSION']._serialized_end=617
  _globals['_PERMISSION_RESOURCETYPE']._serialized_start=261
  _globals['_PERMISSION_RESOURCETYPE']._serialized_end=479
  _globals['_PERMISSION_PERMISSIONTYPE']._serialized_start=481
  _globals['_PERMISSION_PERMISSIONTYPE']._serialized_end=558
  _globals['_PERMISSION_COLLECTIONTYPE']._serialized_start=560
  _globals['_PERMISSION_COLLECTIONTYPE']._serialized_end=617
  _globals['_PERMISSIONCREATEREQUEST']._serialized_start=619
  _globals['_PERMISSIONCREATEREQUEST']._serialized_end=697
  _globals['_PERMISSIONCREATERESPONSE']._serialized_start=699
  _globals['_PERMISSIONCREATERESPONSE']._serialized_end=746
  _globals['_PERMISSIONDELETEREQUEST']._serialized_start=748
  _globals['_PERMISSIONDELETEREQUEST']._serialized_end=826
  _globals['_PERMISSIONDELETERESPONSE']._serialized_start=828
  _globals['_PERMISSIONDELETERESPONSE']._serialized_end=875
  _globals['_PERMISSIONAPI']._serialized_start=878
  _globals['_PERMISSIONAPI']._serialized_end=1095
# @@protoc_insertion_point(module_scope)
