# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: notification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12notification.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x13\x63ommon_models.proto\"\xc3\x01\n\x19SubscriptionCreateRequest\x12\x46\n\rsubscriptions\x18\x01 \x03(\x0b\x32/.oi.papi.SubscriptionCreateRequest.Subscription\x1a^\n\x0cSubscription\x12\x10\n\x08topic_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12(\n\x07\x66ilters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"K\n\x1aSubscriptionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x18\n\x10subscription_ids\x18\x02 \x03(\t\"(\n\x05Topic\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\'\n\x10TopicListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\"H\n\x11TopicListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1e\n\x06topics\x18\x02 \x03(\x0b\x32\x0e.oi.papi.Topic\"#\n\x07\x43hannel\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\")\n\x12\x43hannelListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\"N\n\x13\x43hannelListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\"\n\x08\x63hannels\x18\x02 \x03(\x0b\x32\x10.oi.papi.Channel\"(\n\x19SubscriptionDeleteRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"1\n\x1aSubscriptionDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xe1\x02\n\x0fNotificationApi\x12^\n\x13\x63reate_subscription\x12\".oi.papi.SubscriptionCreateRequest\x1a#.oi.papi.SubscriptionCreateResponse\x12\x43\n\nlist_topic\x12\x19.oi.papi.TopicListRequest\x1a\x1a.oi.papi.TopicListResponse\x12I\n\x0clist_channel\x12\x1b.oi.papi.ChannelListRequest\x1a\x1c.oi.papi.ChannelListResponse\x12^\n\x13\x64\x65lete_subscription\x12\".oi.papi.SubscriptionDeleteRequest\x1a#.oi.papi.SubscriptionDeleteResponseP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notification_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SUBSCRIPTIONCREATEREQUEST']._serialized_start=83
  _globals['_SUBSCRIPTIONCREATEREQUEST']._serialized_end=278
  _globals['_SUBSCRIPTIONCREATEREQUEST_SUBSCRIPTION']._serialized_start=184
  _globals['_SUBSCRIPTIONCREATEREQUEST_SUBSCRIPTION']._serialized_end=278
  _globals['_SUBSCRIPTIONCREATERESPONSE']._serialized_start=280
  _globals['_SUBSCRIPTIONCREATERESPONSE']._serialized_end=355
  _globals['_TOPIC']._serialized_start=357
  _globals['_TOPIC']._serialized_end=397
  _globals['_TOPICLISTREQUEST']._serialized_start=399
  _globals['_TOPICLISTREQUEST']._serialized_end=438
  _globals['_TOPICLISTRESPONSE']._serialized_start=440
  _globals['_TOPICLISTRESPONSE']._serialized_end=512
  _globals['_CHANNEL']._serialized_start=514
  _globals['_CHANNEL']._serialized_end=549
  _globals['_CHANNELLISTREQUEST']._serialized_start=551
  _globals['_CHANNELLISTREQUEST']._serialized_end=592
  _globals['_CHANNELLISTRESPONSE']._serialized_start=594
  _globals['_CHANNELLISTRESPONSE']._serialized_end=672
  _globals['_SUBSCRIPTIONDELETEREQUEST']._serialized_start=674
  _globals['_SUBSCRIPTIONDELETEREQUEST']._serialized_end=714
  _globals['_SUBSCRIPTIONDELETERESPONSE']._serialized_start=716
  _globals['_SUBSCRIPTIONDELETERESPONSE']._serialized_end=765
  _globals['_NOTIFICATIONAPI']._serialized_start=768
  _globals['_NOTIFICATIONAPI']._serialized_end=1121
# @@protoc_insertion_point(module_scope)
